@@ -155,6 +155,8 @@ class bigjob(api.base.bigjob):
         """  
         
         self.coordination_url = coordination_url
+        if self.coordination_url==None:
+            logger.error("Coordination URL not set. Exiting BigJob.")
         #self.launch_method=""
         self.__filemanager=None
         
@@ -259,6 +261,7 @@ class bigjob(api.base.bigjob):
         if project !=None:
             jd.project=project       
         if walltime!=None:
+            logger.debug("setting walltime to: " + str(walltime))
             if is_bliss:
                 jd.wall_time_limit=int(walltime)
             else:
@@ -384,7 +387,7 @@ class bigjob(api.base.bigjob):
             jd.arguments = ["python", "-c", bootstrap_script]
             jd.executable = "/usr/bin/env"           
       
-        logger.debug("Working directory: " + jd.working_directory)
+        logger.debug("Working directory: " + jd.working_directory + " Job Description: " + str(jd))
         
         jd.output = os.path.join(self.working_directory, "stdout-" + self.uuid + "-agent.txt")
         jd.error = os.path.join(self.working_directory, "stderr-" + self.uuid + "-agent.txt")
@@ -462,7 +465,8 @@ class bigjob(api.base.bigjob):
             if self.url.scheme.startswith("condor")==False:
                 self.job.cancel()
             else:
-                logger.debug("Output files are being transfered to file: outpt.tar.gz. Please wait until transfer is complete.")
+                pass
+                #logger.debug("Output files are being transfered to file: outpt.tar.gz. Please wait until transfer is complete.")
         except:
             pass
             #traceback.print_stack()
