@@ -35,8 +35,8 @@ if __name__ == "__main__":
                                 #"service_url": "ssh://localhost/tmp/pilot-data-" + str(uuid.uuid1()),
                                 "affinity_datacenter_label": "us-east",              
                                 "affinity_machine_label": "",
-                                "access_key_id":"8MCXRAMXMHDYKWNKXZ8WF",
-                                "secret_access_key":"YrcUqSw2Arxshrh3ZtenkxerWwCWdMTKvZYoLPAo"
+                                "access_key_id":"x",
+                                "secret_access_key":"x"
                              }
     
     
@@ -68,7 +68,7 @@ if __name__ == "__main__":
                              'affinity_machine_label': "", 
                              # cloud specific attributes
                              #"vm_id":"ami-d7f742be",
-                             "vm_id": "ami-7e37173b",
+                             "vm_id": "ami-5c3b1b19",
                              "vm_ssh_username":"ubuntu",
                              "vm_ssh_keyname":"MyKey",
                              "vm_ssh_keyfile":"/Users/luckow/.ssh/id_rsa",
@@ -136,4 +136,4 @@ if __name__ == "__main__":
     logger.info("Terminate Pilot Compute/Data Service")
     compute_data_service.cancel()
     pilot_data_service.cancel()
-    pilot_compute_service.cancel()
\ No newline at end of file
+    pilot_compute_service.cancel()
